## Fraud Detection Data

#### _Source: Kaggle_

### About the Dataset
This is a simulated credit card transaction dataset containing legitimate and fraud transactions from the duration 1st Jan 2019 - 31st Dec 2020. It covers credit cards of 1000 customers doing transactions with a pool of 800 merchants.

Following are the columns in the dataset:

- trans_date_trans_time : Date and time of Transaction occuring
- cc_num : Credit card number
- merchant : Organization where the transaction occured
- category : Type of merchant/organization. Eg home, food dining etc
- amt: Amount of transaction
- first : First name of the person who did transaction
- last : Last name of the person who did transaction
- gender
- street
- city
- state
- zip
- lat : Geographical Latitude coordinates of the customer where transaction occured
- long : Geographical Longitude coordinates of the customer where transaction occured
- city_pop : City Population
- job : Current Job of the person who did transaction
- dob : Date of birth
- trans_num : Transaction number
- merch_lat : Geographical Latitude coordinates of the merhcant where transaction occured
- merch_long : Geographical Latitude coordinates of the merhcant where transaction occured
- is_fraud : Variable that tells whether a transaction is fraud or not
